### Encoding: latin1

### Name: empcop.test
### Title: Multivariate independence test based on the empirical copula
###   process
### Aliases: empcop.test empcop.simulate dependogram
### Keywords: htest

### ** Examples

## Consider the following example taken from
## Genest and Remillard (2004), p 352:

x <- matrix(rnorm(500),100,5)
x[,1] <- abs(x[,1]) * sign(x[,2] * x[,3])
x[,5] <- x[,4]/2 + sqrt(3) * x[,5]/2

## Not run: 
##D ## In order to test for independence "within" x, the first step consists
##D ## in simulating the distribution of the test statistics under
##D ## independence for the same sample size and dimension,
##D ## i.e. n=100 and p=5. As we are going to consider all the subsets of
##D ## {1,...,5} whose cardinality is between 2 and 5, we set m=5.
##D ## This may take a while...
##D 
##D d <- empcop.simulate(100,5,5)
##D 
##D ## The next step consists in performing the test itself:
##D 
##D test <- empcop.test(x,d,5)
##D 
##D ## Let us see the results:
##D 
##D test
##D 
##D ## Display the dependogram:
##D 
##D dependogram(test)
##D 
##D ## We could have tested for a weaker form of independence, for instance,
##D ## by only computing statistics for subsets whose cardinality is between 2
##D ## and 3:
##D 
##D test <- empcop.test(x,d,3)
##D test
##D dependogram(test)
##D 
##D ## Consider now the following data:
##D y <- matrix(runif(500),100,5)
##D ## and perform the test:
##D test <- empcop.test(y,d,3)
##D test
##D dependogram(test)
## End(Not run)

## NB: In order to save d for future use, the save function can be used.



